@@ -2,7 +2,7 @@
 
 #==============================================================================#
 # exerb.rb
-# $Id: exerb.rb,v 1.19 2002/11/14 04:23:35 yuya Exp $
+# $Id: exerb.rb,v 1.20 2002/12/27 06:34:45 yuya Exp $
 #==============================================================================#
 
 require 'getoptlong'
@@ -48,7 +48,10 @@ module ExerbCommand
       }
     end
 
-    arcbin  = Exerb::Binary::Archive.new(arc.pack, options[:compress])
+    compress = options[:compress]
+    compress ||= rbc.compress
+
+    arcbin  = Exerb::Binary::Archive.new(arc.pack, compress)
     corebin = Exerb::Binary::Core.new_from_file(corefile)
     exebin  = Exerb::Binary::Executable.new(arcbin, corebin)
     exebin.selfcheck
@@ -138,6 +141,7 @@ module ExerbCommand
       @corename = nil
       @corefile = nil
       @output   = nil
+      @compress = false
 
       File.open(filepath) { |file|
         file.to_a
@@ -153,6 +157,7 @@ module ExerbCommand
         when 'corename' then @corename = p1
         when 'corefile' then @corefile = File.expand_path(p1, @basedir)
         when 'output'   then @output   = File.expand_path(p1, @basedir)
+        when 'compress' then @compress = yesno(p1)
         when 'script'   then @archive.add_script(p1, File.expand_path(p2 || p1, @basedir))
         when 'library'  then @archive.add_dll(p1, File.expand_path(p2 || p1, @basedir))
         else raise "syntax error : #{type}"
@@ -160,7 +165,16 @@ module ExerbCommand
       }
     end
 
-    attr_reader :archive, :corename, :corefile, :output
+    attr_reader :archive, :corename, :corefile, :output, :compress
+
+    def yesno(str)
+      case str
+      when 'yes' then true
+      when 'no'  then false
+      else raise 'yes or no'
+      end
+    end
+    private :yesno
 
   end # RecipeFile
 
